@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/IO/ModelOutput.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -82,21 +82,26 @@ ModelOutput::ModelOutput(
 		LabelDescription & labelDescription, 
 		ProbaDescription & probaDescription) 
 {
-	_modelType = modelType;
-	_nbCluster = nbCluster;
-	_strategyRunError = NOERROR.clone(); // TODO ??
-	if (*(dynamic_cast<Exception*> (_strategyRunError)) == NOERROR) {
-		_probaDescription = new ProbaDescription(probaDescription);
-		_labelDescription = new LabelDescription(labelDescription);
-		_parameterDescription = new ParameterDescription(parameterDescription);
-	}
-	else {
-		_probaDescription = NULL;
-		_labelDescription = NULL;
-		_parameterDescription = NULL;
-	}
+  _modelType = modelType;
+  _nbCluster = nbCluster;
+  _strategyRunError = NOERROR.clone(); // TODO ??
+  if (*(dynamic_cast<Exception*> (_strategyRunError)) == NOERROR) {
+    _probaDescription = new ProbaDescription(probaDescription);
+    _labelDescription = new LabelDescription(labelDescription);
+    _parameterDescription = new ParameterDescription(parameterDescription);
+    for (int64_t i = 0; i < criterionOutput.size(); i++) {
+      _criterionOutput[i].setValue(criterionOutput[i]->getValue());
+      _criterionOutput[i].setCriterionName(criterionOutput[i]->getCriterionName());
+      _criterionOutput[i].setError(criterionOutput[i]->getError());
+    }
+  }
+  else {
+    _probaDescription = NULL;
+    _labelDescription = NULL;
+    _parameterDescription = NULL;
+  }
 
-	_likelihood = likelihood;
+  _likelihood = likelihood;
 }
 
 //------------------------------
