@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Model/ModelType.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -59,7 +59,10 @@ ModelType::ModelType(const ModelType & iModelType) {
 
 ModelType::~ModelType() {
 	if (_tabSubDimensionFree) {
-		delete [] _tabSubDimensionFree;
+		//delete [] _tabSubDimensionFree; //TODO [bauder]: there is something wrong with this variable, 
+		                                  //maybe reaffected to something already deleted.
+		                                  //Should be fixed cleanly by tracking its affectations.
+		                                  //Test after debug by running example da3.
 		_tabSubDimensionFree = NULL;
 	}
 }
