@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/GaussianGeneralParameter.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -56,6 +56,14 @@ public:
 			int64_t iPbDimension, 
 			ModelType * iModelType, 
 			std::string & iFileName);
+  // For heterogeneous models
+	GaussianGeneralParameter(
+			int64_t iNbCluster, 
+			int64_t iPbDimension, 
+			ModelType * iModelType, 
+			std::string & iFileName,
+      int64_t iNbVariable_binary,
+      std::vector< int64_t > inbFactor);
 	GaussianGeneralParameter(
 			int64_t iNbCluster, 
 			int64_t iPbDimension, 
